Class: Brevo::EventsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/brevo/api/events_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EventsApi



19
20
21
# File 'lib/brevo/api/events_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/brevo/api/events_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_event(event, opts = {}) ⇒ nil

Create an event Create an event to track a contact’s interaction.



37
38
39
40
# File 'lib/brevo/api/events_api.rb', line 37

def create_event(event, opts = {})
  create_event_with_http_info(event, opts)
  nil
end

#create_event_with_http_info(event, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Create an event Create an event to track a contact&#39;s interaction.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/brevo/api/events_api.rb', line 47

def create_event_with_http_info(event, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EventsApi.create_event ...'
  end
  # verify the required parameter 'event' is set
  if @api_client.config.client_side_validation && event.nil?
    fail ArgumentError, "Missing the required parameter 'event' when calling EventsApi.create_event"
  end
  # resource path
  local_var_path = '/events'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(event)
  auth_names = ['api-key', 'partner-key']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EventsApi#create_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#setUserAgent(user_agent) ⇒ Object

Set custom user_agent if explicitly passed in api default will still remain Swagger-Codegen/#VERSION/ruby



25
26
27
28
29
30
# File 'lib/brevo/api/events_api.rb', line 25

def setUserAgent(user_agent)
  @user_agent = user_agent
  if user_agent.is_a?(String) && user_agent.downcase.start_with?('brevo_')
    @api_client.default_headers['User-Agent'] = @user_agent
  end
end