Class: Brevo::MainRewardPageObj

Inherits:
Object
  • Object
show all
Defined in:
lib/brevo/models/main_reward_page_obj.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MainRewardPageObj

Initializes the object



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/brevo/models/main_reward_page_obj.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'createdAt')
    self.created_at = attributes[:'createdAt']
  end

  if attributes.has_key?(:'endDate')
    self.end_date = attributes[:'endDate']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'loyaltyProgramId')
    self.loyalty_program_id = attributes[:'loyaltyProgramId']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'publicImage')
    self.public_image = attributes[:'publicImage']
  end

  if attributes.has_key?(:'startDate')
    self.start_date = attributes[:'startDate']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'updatedAt')
    self.updated_at = attributes[:'updatedAt']
  end
end

Instance Attribute Details

#created_atObject

Timestamp for when this reward was created



18
19
20
# File 'lib/brevo/models/main_reward_page_obj.rb', line 18

def created_at
  @created_at
end

#end_dateObject

Timestamp for when this reward attributed was ended



21
22
23
# File 'lib/brevo/models/main_reward_page_obj.rb', line 21

def end_date
  @end_date
end

#idObject

Unique identifier for the reward



24
25
26
# File 'lib/brevo/models/main_reward_page_obj.rb', line 24

def id
  @id
end

#loyalty_program_idObject

Loyalty Program to which current reward is associated to



27
28
29
# File 'lib/brevo/models/main_reward_page_obj.rb', line 27

def loyalty_program_id
  @loyalty_program_id
end

#nameObject

Name of the reward



30
31
32
# File 'lib/brevo/models/main_reward_page_obj.rb', line 30

def name
  @name
end

#public_imageObject

Public image of the reward



33
34
35
# File 'lib/brevo/models/main_reward_page_obj.rb', line 33

def public_image
  @public_image
end

#start_dateObject

Timestamp for when this reward attributed was started



36
37
38
# File 'lib/brevo/models/main_reward_page_obj.rb', line 36

def start_date
  @start_date
end

#stateObject

State of the reward



39
40
41
# File 'lib/brevo/models/main_reward_page_obj.rb', line 39

def state
  @state
end

#updated_atObject

Timestamp for when this reward attributed was updated



42
43
44
# File 'lib/brevo/models/main_reward_page_obj.rb', line 42

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/brevo/models/main_reward_page_obj.rb', line 45

def self.attribute_map
  {
    :'created_at' => :'createdAt',
    :'end_date' => :'endDate',
    :'id' => :'id',
    :'loyalty_program_id' => :'loyaltyProgramId',
    :'name' => :'name',
    :'public_image' => :'publicImage',
    :'start_date' => :'startDate',
    :'state' => :'state',
    :'updated_at' => :'updatedAt'
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/brevo/models/main_reward_page_obj.rb', line 60

def self.swagger_types
  {
    :'created_at' => :'DateTime',
    :'end_date' => :'DateTime',
    :'id' => :'String',
    :'loyalty_program_id' => :'String',
    :'name' => :'String',
    :'public_image' => :'String',
    :'start_date' => :'DateTime',
    :'state' => :'String',
    :'updated_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/brevo/models/main_reward_page_obj.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      end_date == o.end_date &&
      id == o.id &&
      loyalty_program_id == o.loyalty_program_id &&
      name == o.name &&
      public_image == o.public_image &&
      start_date == o.start_date &&
      state == o.state &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/brevo/models/main_reward_page_obj.rb', line 184

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Brevo.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/brevo/models/main_reward_page_obj.rb', line 250

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/brevo/models/main_reward_page_obj.rb', line 163

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


150
151
152
# File 'lib/brevo/models/main_reward_page_obj.rb', line 150

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



156
157
158
# File 'lib/brevo/models/main_reward_page_obj.rb', line 156

def hash
  [created_at, end_date, id, loyalty_program_id, name, public_image, start_date, state, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



121
122
123
124
# File 'lib/brevo/models/main_reward_page_obj.rb', line 121

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



230
231
232
# File 'lib/brevo/models/main_reward_page_obj.rb', line 230

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
# File 'lib/brevo/models/main_reward_page_obj.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



224
225
226
# File 'lib/brevo/models/main_reward_page_obj.rb', line 224

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



128
129
130
# File 'lib/brevo/models/main_reward_page_obj.rb', line 128

def valid?
  true
end